[gnome-color-manager] trivial: use the en_US spelling of recognize



commit 5853c3aa4a0e4a2e1fad0dd8a90009a5460f8d87
Author: Richard Hughes <richard hughsie com>
Date:   Sat Mar 6 21:40:03 2010 +0000

    trivial: use the en_US spelling of recognize

 src/gcm-colorimeter.c   |   12 ++++++------
 src/gcm-device-cups.c   |    2 +-
 src/gcm-device-xrandr.c |    4 ++--
 src/gcm-device.c        |    8 ++++----
 src/gcm-profile-lcms1.c |    6 +++---
 src/gcm-profile-store.c |    2 +-
 6 files changed, 17 insertions(+), 17 deletions(-)
---
diff --git a/src/gcm-device-cups.c b/src/gcm-device-cups.c
index 643636d..5d475f9 100644
--- a/src/gcm-device-cups.c
+++ b/src/gcm-device-cups.c
@@ -132,7 +132,7 @@ gcm_device_cups_set_from_dest (GcmDevice *device, http_t *http, cups_dest_t dest
 			else if (g_strcmp0 (value, "CMYK") == 0)
 				colorspace = GCM_COLORSPACE_ENUM_CMYK;
 			else
-				egg_warning ("colorspace not recognised: %s", value);
+				egg_warning ("colorspace not recognized: %s", value);
 		} else if (g_strcmp0 (keyword, "cupsICCProfile") == 0) {
 			/* FIXME: possibly map from http://localhost:port/profiles/dave.icc to ~/.icc/color/dave.icc */
 			profile_filename = g_strdup (value);
diff --git a/src/gcm-device-xrandr.c b/src/gcm-device-xrandr.c
index 8d3d2b2..8a465a8 100644
--- a/src/gcm-device-xrandr.c
+++ b/src/gcm-device-xrandr.c
@@ -321,7 +321,7 @@ gcm_device_xrandr_get_gamma_size (GcmDeviceXrandr *device_xrandr, GnomeRRCrtc *c
 	if (priv->gamma_size > 0)
 		return priv->gamma_size;
 
-	/* get id that X recognises */
+	/* get id that X recognizes */
 	id = gnome_rr_crtc_get_id (crtc);
 
 	/* get the value, and catch errors */
@@ -406,7 +406,7 @@ gcm_device_xrandr_apply_for_crtc (GcmDeviceXrandr *device_xrandr, GnomeRRCrtc *c
 		crtc_gamma->blue[i] = data->blue;
 	}
 
-	/* get id that X recognises */
+	/* get id that X recognizes */
 	id = gnome_rr_crtc_get_id (crtc);
 
 	/* get the value, and catch errors */
diff --git a/src/gcm-device.c b/src/gcm-device.c
index ca67a5f..85878de 100644
--- a/src/gcm-device.c
+++ b/src/gcm-device.c
@@ -746,17 +746,17 @@ gcm_device_test (EggTest *test)
 	egg_test_assert (test, device != NULL);
 
 	/************************************************************/
-	egg_test_title (test, "convert to recognised enum");
+	egg_test_title (test, "convert to recognized enum");
 	type_enum = gcm_device_type_enum_from_string ("scanner");
 	egg_test_assert (test, (type_enum == GCM_DEVICE_TYPE_ENUM_SCANNER));
 
 	/************************************************************/
-	egg_test_title (test, "convert to unrecognised enum");
+	egg_test_title (test, "convert to unrecognized enum");
 	type_enum = gcm_device_type_enum_from_string ("xxx");
 	egg_test_assert (test, (type_enum == GCM_DEVICE_TYPE_ENUM_UNKNOWN));
 
 	/************************************************************/
-	egg_test_title (test, "convert from recognised enum");
+	egg_test_title (test, "convert from recognized enum");
 	type = gcm_device_type_enum_to_string (GCM_DEVICE_TYPE_ENUM_SCANNER);
 	if (g_strcmp0 (type, "scanner") == 0)
 		egg_test_success (test, NULL);
@@ -764,7 +764,7 @@ gcm_device_test (EggTest *test)
 		egg_test_failed (test, "invalid value: %s", type);
 
 	/************************************************************/
-	egg_test_title (test, "convert from unrecognised enum");
+	egg_test_title (test, "convert from unrecognized enum");
 	type = gcm_device_type_enum_to_string (GCM_DEVICE_TYPE_ENUM_UNKNOWN);
 	if (g_strcmp0 (type, "unknown") == 0)
 		egg_test_success (test, NULL);
diff --git a/src/gcm-profile-store.c b/src/gcm-profile-store.c
index 2f7a34f..9bd178b 100644
--- a/src/gcm-profile-store.c
+++ b/src/gcm-profile-store.c
@@ -262,7 +262,7 @@ gcm_profile_store_add_profiles_for_path (GcmProfileStore *profile_store, const g
 		}
 
 		/* invalid file */
-		egg_debug ("not recognised as ICC profile: %s", path);
+		egg_debug ("not recognized as ICC profile: %s", path);
 		goto out;
 	}
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gcm-colorimeter.c b/src/gcm-colorimeter.c
index 28265b4..3be05f7 100644
--- a/src/gcm-colorimeter.c
+++ b/src/gcm-colorimeter.c
@@ -325,7 +325,7 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 	} else if (priv->model != NULL && g_ascii_strcasecmp (priv->model, "Monitor Spyder") == 0) {
 		priv->colorimeter_kind = GCM_COLORIMETER_KIND_SPYDER;
 	} else if (priv->model != NULL) {
-		egg_warning ("Failed to recognise color device: %s", priv->model);
+		egg_warning ("Failed to recognize color device: %s", priv->model);
 
 		/* show dialog, in order to help the project */
 		if (!priv->shown_warning) {
@@ -333,10 +333,10 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 							 GTK_DIALOG_MODAL,
 							 GTK_MESSAGE_INFO,
 							 GTK_BUTTONS_OK,
-							 /* TRANSLATORS: this is when the device is not recognised */
-							 _("Measuring instrument not recognised"));
+							 /* TRANSLATORS: this is when the device is not recognized */
+							 _("Measuring instrument not recognized"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-								  "Could not recognise attached measuring instrument '%s'. "
+								  "Could not recognize attached measuring instrument '%s'. "
 								  "It should work okay, but if you want to help the project, "
 								  "please visit %s and supply the required information.",
 								  priv->model, "http://live.gnome.org/GnomeColorManager/Help";);
@@ -347,7 +347,7 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 		}
 		priv->colorimeter_kind = GCM_COLORIMETER_KIND_UNKNOWN;
 	} else {
-		egg_warning ("Failed to recognise color device");
+		egg_warning ("Failed to recognize color device");
 
 		/* show dialog, in order to help the project */
 			if (!priv->shown_warning) {
@@ -355,7 +355,7 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 							 GTK_DIALOG_MODAL,
 							 GTK_MESSAGE_INFO,
 							 GTK_BUTTONS_OK,
 							 /* TRANSLATORS: this is when the device is not recognised */
 							 _("Measuring instrument not registered"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 								  "The attached measuring devicer device has not been registered in usb.ids. "
@@ -355,7 +355,7 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 							 GTK_MESSAGE_INFO,
 							 GTK_BUTTONS_OK,
-							 /* TRANSLATORS: this is when the device is not recognised */
+							 /* TRANSLATORS: this is when the device is not recognized */
 							 _("Measuring instrument not registered"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
diff --git a/src/gcm-profile-lcms1.c b/src/gcm-profile-lcms1.c
index 7bac20c..6b890d9 100644
--- a/src/gcm-profile-lcms1.c
+++ b/src/gcm-profile-lcms1.c
@@ -314,7 +314,7 @@ gcm_parser_load_icc_vcgt (GcmProfileLcms1 *profile_lcms1, const guint8 *data, gu
 	}
 
 	/* we didn't understand the encoding */
-	egg_warning ("gamma type encoding not recognised");
+	egg_warning ("gamma type encoding not recognized");
 out:
 	return ret;
 }
@@ -396,9 +396,9 @@ gcm_profile_lcms1_parse_multi_localized_unicode (GcmProfileLcms1 *profile_lcms1,
 		goto out;
 	}
 
 	/* an unrecognised tag */
 	for (i=0x0; i<0x1c; i++) {
-		egg_warning ("unrecognised text tag");
+		egg_warning ("unrecognized text tag");
 		if (data[i] >= 'A' && data[i] <= 'z')
 			egg_debug ("%i\t%c (%i)", i, data[i], data[i]);
 		else
@@ -396,9 +396,9 @@ gcm_profile_lcms1_parse_multi_localized_unicode (GcmProfileLcms1 *profile_lcms1,
 	}
 
-	/* an unrecognised tag */
+	/* an unrecognized tag */
 	for (i=0x0; i<0x1c; i++) {